==> lesserwiki-0.1.0.zip: lesserwiki-0.1.0/app/models/chunks/engines.rb <==
$: << File.dirname(__FILE__) + "../../lib"

#require 'redcloth'
#require 'bluecloth_tweaked'
#require 'rdocsupport'
require 'chunks/chunk'

# The markup engines are Chunks that call the one of RedCloth
# or RDoc to convert text. This markup occurs when the chunk is required
# to mask itself.
module Engines
  class AbstractEngine < Chunk::Abstract

    # Create a new chunk for the whole content and replace it with its mask.
    def self.apply_to(content, tiddlers)
      new_chunk = self.new(content)
      #content.replace(new_chunk.mask)
      content.replace(new_chunk.mask.gsub(/<a\s+href=/, %{<a class="external" target="_blank" title="External link" href=}))
    end

    private 

    # Never create engines by constructor - use apply_to instead
    def initialize(content)
      @content = content
    end

  end

  class Textile < AbstractEngine
    def mask
      redcloth = RedCloth.new(@content, [:hard_breaks] + @content.options[:engine_opts])
      redcloth.filter_html = false
      redcloth.no_span_caps = false  
      redcloth.to_html(:textile)
    end
  end

  #class Markdown < AbstractEngine
  #  def mask
  #    BlueCloth.new(@content, @content.options[:engine_opts]).to_html
  #  end
  #end

  class Mixed < AbstractEngine
    def mask
      redcloth = RedCloth.new(@content, @content.options[:engine_opts])
      redcloth.filter_html = false
      redcloth.no_span_caps = false
      redcloth.to_html
    end
  end

  #class RDoc < AbstractEngine
  #  def mask
  #    RDocSupport::RDocFormatter.new(@content).to_html
  #  end
  #end

  MAP = {
    :textile => Textile,
    #:markdown => Markdown,
    :mixed => Mixed,
    #:rdoc => RDoc
  }
  MAP.default = Textile
end

==> lesserwiki-0.2.0.zip: lesserwiki-0.2.0/app/models/chunks/engines.rb <==
$: << File.dirname(__FILE__) + "../../lib"

#require 'redcloth'
#require 'bluecloth_tweaked'
#require 'rdocsupport'
require 'chunks/chunk'

# The markup engines are Chunks that call the one of RedCloth
# or RDoc to convert text. This markup occurs when the chunk is required
# to mask itself.
module Engines
  class AbstractEngine < Chunk::Abstract

    # Create a new chunk for the whole content and replace it with its mask.
    def self.apply_to(content, tiddlers)
      new_chunk = self.new(content)
      content.replace(new_chunk.mask.gsub(/<a\s+href="([^"]*)"([^>]*)>/, %{<a class="external" target="_blank" title="#{message("external")}" href="\\1" \\2>}))
    end

    private 

    # Never create engines by constructor - use apply_to instead
    def initialize(content)
      @content = content
    end

  end

  class Textile < AbstractEngine
    def mask
      redcloth = RedCloth.new(@content, [:hard_breaks] + @content.options[:engine_opts])
      redcloth.filter_html = false
      redcloth.no_span_caps = true
      redcloth.to_html(:textile)
    end
  end

  #class Markdown < AbstractEngine
  #  def mask
  #    BlueCloth.new(@content, @content.options[:engine_opts]).to_html
  #  end
  #end

  class Mixed < AbstractEngine
    def mask
      redcloth = RedCloth.new(@content, @content.options[:engine_opts])
      redcloth.filter_html = false
      redcloth.no_span_caps = false
      redcloth.to_html
    end
  end

  #class RDoc < AbstractEngine
  #  def mask
  #    RDocSupport::RDocFormatter.new(@content).to_html
  #  end
  #end

  MAP = {
    :textile => Textile,
    #:markdown => Markdown,
    :mixed => Mixed,
    #:rdoc => RDoc
  }
  MAP.default = Textile
end
